internal

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: MIT Imports: 19 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var AdvancedBypassJS string
var BypassJS string
var DumpJS string

Functions

func CompileOrLoad added in v1.1.0

func CompileOrLoad(path string) (string, error)

func GenerateIPA

func GenerateIPA(payloadPath, outputDir, ipaName string, fileDict map[string]string) error

func GetApplications added in v1.1.0

func GetApplications(device frida.DeviceInt) ([]*frida.Application, error)

func GetUSBDevice

func GetUSBDevice(ctx context.Context) (frida.DeviceInt, error)

func InjectBypass added in v1.1.0

func InjectBypass(session *frida.Session, script string) error

Call while the process is still suspended (before Resume) so hooks are in place before any app code runs.

func ListApplications

func ListApplications(device frida.DeviceInt) error

func OpenApp added in v1.1.0

func OpenApp(ctx context.Context, device frida.DeviceInt, target, bypassScript string) (*frida.Session, string, error)

func OpenTargetApp

func OpenTargetApp(ctx context.Context, device frida.DeviceInt, nameOrBundleID string) (session *frida.Session, displayName, bundleID string, err error)

func StartDump

func StartDump(ctx context.Context, session *frida.Session, sftpClient *sftp.Client, payloadPath, outputDir, ipaName string) (err error)

Types

type SpawnResult added in v1.1.1

type SpawnResult struct {
	Session     *frida.Session
	PID         int
	DisplayName string
	BundleID    string
	Suspended   bool
}

func SpawnAndAttach added in v1.1.0

func SpawnAndAttach(ctx context.Context, device frida.DeviceInt, nameOrBundleID string) (SpawnResult, error)

Does NOT resume the process; call device.Resume(pid) after injecting any bypass script. If the app is already running, attaches directly without re-spawning; Suspended is false in that case.

Directories

Path Synopsis

Jump to